@@ -1694,8 +1694,8 @@ namespace PlansPlant
     Opt = QFileDialog::DontUseNativeDialog;
 #endif
     QString NewName = QFileDialog::getOpenFileName( this, tr( "Open file:" ), Model->file_name(),
-#ifdef Q_WS_MAEMO_5 // Translated strings don't work
-						    "Plans Plant files (*.plansplant); All files (*)",
+#ifdef Q_WS_MAEMO_5 // Don't use filters because there's no way to change them.
+						    QString(),
 #else // !Q_WS_MAEMO_5
 						    tr( "Plans Plant files" ) + " (*.plansplant);;" + tr( "All files" ) + " (*)",
 #endif // Q_WS_MAEMO_5
@@ -1747,7 +1747,7 @@ namespace PlansPlant
 #endif
       QString NewName = QFileDialog::getSaveFileName( this, tr( "Select file for saving:" ), Model->file_name(),
 #ifdef Q_WS_MAEMO_5
-						      "Plans Plant files (*.plansplant);; All files (*)",
+						      "Plan (*.plansplant)",
 #else // !Q_WS_MAEMO_5
 						      tr( "Plans Plant files" ) + " (*.plansplant);;" + tr( "All files" ) + " (*)",
 #endif // Q_WS_MAEMO_5
@@ -1781,7 +1781,7 @@ namespace PlansPlant
       ExportName += BaseName + ".html";
       ExportName = QFileDialog::getSaveFileName( this, tr( "Export to HTML. Select file:" ), ExportName,
 #ifdef Q_WS_MAEMO_5
-						 "HTML files (*.html *.htm);; All files (*)",
+						 "HTML (*.html)",
 #else // !Q_WS_MAEMO_5
 						 tr( "HTML files" ) + " (*.html *.htm);;" + tr( "All files" ) + " (*)",
 #endif // Q_WS_MAEMO_5
